﻿using System;
using ThumbnailLibrary;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Media.Imaging;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace CSharpThumbnails
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage
    {
        private static WriteableBitmap LoadBitmap(IRandomAccessStream stream)
        {
            var bitmap = new WriteableBitmap(1, 1);
            bitmap.SetSource(stream);
            bitmap.Invalidate();
            return bitmap;
        }

        public MainPage()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
        }

        private async void Button_Click_1(object sender, RoutedEventArgs e)
        {
            var openPicker = new FileOpenPicker
                {
                    ViewMode = PickerViewMode.Thumbnail, 
                    SuggestedStartLocation = PickerLocationId.PicturesLibrary
                };
            openPicker.FileTypeFilter.Add(".jpg");
            openPicker.FileTypeFilter.Add(".jpeg");
            openPicker.FileTypeFilter.Add(".png");

            var file = await openPicker.PickSingleFileAsync();

            if (file == null)
            {
                var dialog = new MessageDialog("No image was selected.");
                await dialog.ShowAsync();
                return;
            }

            using (var fileStream = await file.OpenReadAsync())
            {
                SourceImage.Source = LoadBitmap(fileStream);
                var maker = new ThumbnailMaker();
                var stream = RandomAccessStreamReference
                    .CreateFromUri(await maker.GenerateThumbnailAsync(file));
                var bitmapImage = new BitmapImage();
                bitmapImage.SetSource(await stream.OpenReadAsync());
                ThumbnailImage.Source = bitmapImage;
            }
        }
    }
}
